#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unliftio
version:              0.2.18
visibility:           public
id:                   unliftio-0.2.18-2kiHcgI4qdj1XlC6DQIVT2
key:                  unliftio-0.2.18-2kiHcgI4qdj1XlC6DQIVT2
license:              MIT
copyright:            2017 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Francesco Mazzoli
homepage:
    https://github.com/fpco/unliftio/tree/master/unliftio#readme

synopsis:
    The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)

description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio>

category:             Control
abi:                  399ddece29539baf6798dec3fc91928f
exposed:              True
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Concurrent
    UnliftIO.Directory UnliftIO.Environment UnliftIO.Exception
    UnliftIO.Foreign UnliftIO.IO UnliftIO.IO.File UnliftIO.IORef
    UnliftIO.Internals.Async UnliftIO.MVar UnliftIO.Memoize
    UnliftIO.Process UnliftIO.QSem UnliftIO.QSemN UnliftIO.STM
    UnliftIO.Temporary UnliftIO.Timeout

hidden-modules:       Paths_unliftio UnliftIO.IO.File.Posix
import-dirs:          /usr/lib/ghc-8.10.5/site-local/unliftio-0.2.18
library-dirs:         /usr/lib/ghc-8.10.5/site-local/unliftio-0.2.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/unliftio-0.2.18
hs-libraries:         HSunliftio-0.2.18-2kiHcgI4qdj1XlC6DQIVT2
depends:
    async-2.2.3-6QbaQgrhqs02Gm74dJYuzp base-4.14.2.0
    bytestring-0.10.12.0 deepseq-1.4.4.0 directory-1.3.6.0
    filepath-1.4.2.1 process-1.6.9.0 stm-2.5.0.1 time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unliftio-core-0.2.0.1-1ibY1oF6Hkc5ZYjZ4yW3Lp

haddock-interfaces:   /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html:         /usr/share/doc/haskell-unliftio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

